==> easybpel.model.bpel.impl-1.2-sources.jar: com/ebmwebsourcing/easybpel/model/bpel/impl/compiler/validation/validator/FromValidatorImpl.java <==
/**
 * easy BPEL software - Copyright (c) 2009 PetalsLink, 
 * http://www.petalslink.com/ 
 *  
 * This library is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU Lesser General Public License as published by the Free 
 * Software Foundation; either version 2.1 of the License, or (at your option) 
 * any later version. This library is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
 * General Public License for more details. 
 *  
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this library; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.validator;

import java.util.logging.Logger;

import javax.xml.namespace.QName;

import org.ow2.easywsdl.extensions.wsdl4bpel.api.Property;
import org.ow2.easywsdl.extensions.wsdl4bpel.api.WSDL4BPELException;
import org.ow2.easywsdl.wsdl.api.Part;
import org.ow2.easywsdl.wsdl.impl.wsdl11.MessageImpl;

import com.ebmwebsourcing.easybpel.model.bpel.api.BPELElement;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELElementImpl;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELException;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELProcess;
import com.ebmwebsourcing.easybpel.model.bpel.api.activity.element.elements4assign.From;
import com.ebmwebsourcing.easybpel.model.bpel.api.compiler.validation.validator.FromValidator;
import com.ebmwebsourcing.easybpel.model.bpel.api.partnerLink.PartnerLink;
import com.ebmwebsourcing.easybpel.model.bpel.api.util.ScopeUtil;
import com.ebmwebsourcing.easybpel.model.bpel.api.variable.BPELVariable;
import com.ebmwebsourcing.easybpel.model.bpel.executable.TFrom;
import com.ebmwebsourcing.easybpel.model.bpel.executable.TTo;
import com.ebmwebsourcing.easybpel.model.bpel.impl.activity.ScopeImpl;
import com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.BPELErrorImpl;
import com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.BPELInfoImpl;
import com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.BPELStaticAnalysisImpl;

public class FromValidatorImpl implements FromValidator {

	private static Logger log = Logger.getLogger(FromValidatorImpl.class.getName());

	private From from = null;

	public FromValidatorImpl(final From from) {
		this.from = from;
	}

	public void validate() {

		// validation
		log.finest("validate from");

		// verify if exist
		BPELVariable var = null;
		if(((TFrom)((BPELElementImpl)this.from).getModel()).getVariable() != null) {
			var = ScopeImpl.findVariableRecursively(new QName(((TFrom)((BPELElementImpl)this.from).getModel()).getVariable()), (BPELElement) ((BPELElementImpl)this.from).getParent());
			if(var == null) {
				BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Impossible to find variable corresponding to the name: " + ((TFrom)((BPELElementImpl)this.from).getModel()).getVariable())));
			} 		
		}

		if(((TFrom)((BPELElementImpl)this.from).getModel()).getPart() != null && var.getMessageType() == null) {
			BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Incorrect. You cannot use \"part\" in \"to\" assignement because the variable \"" + ((TFrom)((BPELElementImpl)this.from).getModel()).getVariable() + "\" is defined as an element or type but not as a messageType")));
		}
		final BPELProcess process = ScopeUtil.getProcess(this.from);
		if(((TFrom)((BPELElementImpl)this.from).getModel()).getPart() != null) {
			if(var != null && var.getMessageType() != null) {
				final MessageImpl msg = process.getImports().getMessage(var.getMessageType());

				final Part part = msg.getPart(new QName(var.getMessageType().getNamespaceURI(), ((TFrom)((BPELElementImpl)this.from).getModel()).getPart()));
				if(part == null) {
					BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Impossible to find part corresponding to the name: " + ((TFrom)((BPELElementImpl)this.from).getModel()).getPart())));
				}

			}
		}

		// find partnerLink
		if(((TFrom)((BPELElementImpl)this.from).getModel()).getPartnerLink() != null) {
			final PartnerLink partnerLink = ScopeUtil.findPartnerLinkRecursively(((TFrom)((BPELElementImpl)this.from).getModel()).getPartnerLink(), (BPELElement) ((BPELElementImpl)this.from).getParent());
			if(partnerLink == null) {
				BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Impossible to find partnerLink corresponding to the name: " + ((TFrom)((BPELElementImpl)this.from).getModel()).getPartnerLink())));
			}
		}

		if(((TFrom)((BPELElementImpl)this.from).getModel()).getEndpointReference() != null) {
			BPELStaticAnalysisImpl.getInstance().addInfo(new BPELInfoImpl(this.from, "In from => [BPEL engine restriction] Sorry, but the attribute endpoint reference is not used for the moment"));
			BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => [BPEL engine restriction] Sorry, but the attribute endpoint reference is not used for the moment")));
		}

		try {
			if(((TFrom)((BPELElementImpl)this.from).getModel()).getProperty() != null) {
				final Property prop = process.getImports().getProperty(((TFrom)((BPELElementImpl)this.from).getModel()).getProperty());
				if(prop == null) {
					BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Impossible to find property corresponding to this name " + ((TFrom)((BPELElementImpl)this.from).getModel()).getProperty())));
				}
			}
		} catch (final WSDL4BPELException e) {
			BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => " + e.getMessage(),e)));
		}

		if((((TFrom)((BPELElementImpl)this.from).getModel()).getExpressionLanguage() != null) && !((TFrom)((BPELElementImpl)this.from).getModel()).getExpressionLanguage().toString().equals("urn:oasis:names:tc:wsbpel:2.0:sublang:xpath1.0")
				&& !((TFrom)((BPELElementImpl)this.from).getModel()).getExpressionLanguage().toString().equals("http://www.w3.org/TR/1999/REC-xpath-19991116")) {
			BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In expressionLanguage => Unknowned uri: " + ((TFrom)((BPELElementImpl)this.from).getModel()).getExpressionLanguage() + ". Only the uri " + "urn:oasis:names:tc:wsbpel:2.0:sublang:xpath1.0" + " and " + "http://www.w3.org/TR/1999/REC-xpath-19991116"+ " are supported")));
		}
	}


}

==> easybpel.model.bpel.impl-1.3-sources.jar: com/ebmwebsourcing/easybpel/model/bpel/impl/compiler/validation/validator/FromValidatorImpl.java <==
/**
 * easy BPEL software - Copyright (c) 2009 PetalsLink, 
 * http://www.petalslink.com/ 
 *  
 * This library is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU Lesser General Public License as published by the Free 
 * Software Foundation; either version 2.1 of the License, or (at your option) 
 * any later version. This library is distributed in the hope that it will be 
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
 * General Public License for more details. 
 *  
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this library; if not, write to the Free Software Foundation, Inc., 
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.validator;

import java.util.logging.Logger;

import javax.xml.namespace.QName;

import org.ow2.easywsdl.extensions.wsdl4bpel.api.Property;
import org.ow2.easywsdl.extensions.wsdl4bpel.api.WSDL4BPELException;
import org.ow2.easywsdl.wsdl.api.Part;
import org.ow2.easywsdl.wsdl.impl.wsdl11.MessageImpl;

import com.ebmwebsourcing.easybpel.model.bpel.api.BPELElement;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELElementImpl;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELException;
import com.ebmwebsourcing.easybpel.model.bpel.api.BPELProcess;
import com.ebmwebsourcing.easybpel.model.bpel.api.activity.element.elements4assign.From;
import com.ebmwebsourcing.easybpel.model.bpel.api.compiler.validation.validator.FromValidator;
import com.ebmwebsourcing.easybpel.model.bpel.api.partnerLink.PartnerLink;
import com.ebmwebsourcing.easybpel.model.bpel.api.util.ScopeUtil;
import com.ebmwebsourcing.easybpel.model.bpel.api.variable.BPELVariable;
import com.ebmwebsourcing.easybpel.model.bpel.executable.TFrom;
import com.ebmwebsourcing.easybpel.model.bpel.executable.TTo;
import com.ebmwebsourcing.easybpel.model.bpel.impl.activity.ScopeImpl;
import com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.BPELErrorImpl;
import com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.BPELInfoImpl;
import com.ebmwebsourcing.easybpel.model.bpel.impl.compiler.validation.BPELStaticAnalysisImpl;

public class FromValidatorImpl implements FromValidator {

	private static Logger log = Logger.getLogger(FromValidatorImpl.class.getName());

	private From from = null;

	public FromValidatorImpl(final From from) {
		this.from = from;
	}

	public void validate() {

		// validation
		log.finest("validate from");

		// verify if exist
		BPELVariable var = null;
		if(((TFrom)((BPELElementImpl)this.from).getModel()).getVariable() != null) {
			var = ScopeImpl.findVariableRecursively(new QName(((TFrom)((BPELElementImpl)this.from).getModel()).getVariable()), (BPELElement) ((BPELElementImpl)this.from).getParent());
			if(var == null) {
				BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Impossible to find variable corresponding to the name: " + ((TFrom)((BPELElementImpl)this.from).getModel()).getVariable())));
			} 		
		}

		if(((TFrom)((BPELElementImpl)this.from).getModel()).getPart() != null && var != null && var.getMessageType() == null) {
			BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Incorrect. You cannot use \"part\" in \"to\" assignement because the variable \"" + ((TFrom)((BPELElementImpl)this.from).getModel()).getVariable() + "\" is defined as an element or type but not as a messageType")));
		}
		final BPELProcess process = ScopeUtil.getProcess(this.from);
		if(((TFrom)((BPELElementImpl)this.from).getModel()).getPart() != null) {
			if(var != null && var.getMessageType() != null) {
				final MessageImpl msg = process.getImports().getMessage(var.getMessageType());

				final Part part = msg.getPart(new QName(var.getMessageType().getNamespaceURI(), ((TFrom)((BPELElementImpl)this.from).getModel()).getPart()));
				if(part == null) {
					BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Impossible to find part corresponding to the name: " + ((TFrom)((BPELElementImpl)this.from).getModel()).getPart())));
				}

			}
		}

		// find partnerLink
		if(((TFrom)((BPELElementImpl)this.from).getModel()).getPartnerLink() != null) {
			final PartnerLink partnerLink = ScopeUtil.findPartnerLinkRecursively(((TFrom)((BPELElementImpl)this.from).getModel()).getPartnerLink(), (BPELElement) ((BPELElementImpl)this.from).getParent());
			if(partnerLink == null) {
				BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Impossible to find partnerLink corresponding to the name: " + ((TFrom)((BPELElementImpl)this.from).getModel()).getPartnerLink())));
			}
		}

		if(((TFrom)((BPELElementImpl)this.from).getModel()).getEndpointReference() != null) {
			BPELStaticAnalysisImpl.getInstance().addInfo(new BPELInfoImpl(this.from, "In from => [BPEL engine restriction] Sorry, but the attribute endpoint reference is not used for the moment"));
			BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => [BPEL engine restriction] Sorry, but the attribute endpoint reference is not used for the moment")));
		}

		try {
			if(((TFrom)((BPELElementImpl)this.from).getModel()).getProperty() != null) {
				final Property prop = process.getImports().getProperty(((TFrom)((BPELElementImpl)this.from).getModel()).getProperty());
				if(prop == null) {
					BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => Impossible to find property corresponding to this name " + ((TFrom)((BPELElementImpl)this.from).getModel()).getProperty())));
				}
			}
		} catch (final WSDL4BPELException e) {
			BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In from => " + e.getMessage(),e)));
		}

		if((((TFrom)((BPELElementImpl)this.from).getModel()).getExpressionLanguage() != null) && !((TFrom)((BPELElementImpl)this.from).getModel()).getExpressionLanguage().toString().equals("urn:oasis:names:tc:wsbpel:2.0:sublang:xpath1.0")
				&& !((TFrom)((BPELElementImpl)this.from).getModel()).getExpressionLanguage().toString().equals("http://www.w3.org/TR/1999/REC-xpath-19991116")) {
			BPELStaticAnalysisImpl.getInstance().addError(new BPELErrorImpl(this.from, new BPELException("In expressionLanguage => Unknowned uri: " + ((TFrom)((BPELElementImpl)this.from).getModel()).getExpressionLanguage() + ". Only the uri " + "urn:oasis:names:tc:wsbpel:2.0:sublang:xpath1.0" + " and " + "http://www.w3.org/TR/1999/REC-xpath-19991116"+ " are supported")));
		}
	}


}
